Driving a 20T202DA2JA VFD, using the (powered) RTC, pressing a button to ask the user to enter the date details over serial, displaying the date on the VFD. Now with added ethernet and NTP to update the time automatically on startup.

Dependencies:   EthernetNetIf mbed DNSResolver NTPClientMin

Revision:
2:f33d74cebc4c
Parent:
1:abc0162903bf
Child:
3:7dcce0aa2535
--- a/main.cpp	Wed Nov 24 22:12:52 2010 +0000
+++ b/main.cpp	Sun Dec 12 01:07:29 2010 +0000
@@ -5,17 +5,17 @@
 // 1 - green - GND
 // 2 - yellow - Vcc
 // 3 - orange - SIO - serial data - MOSI - p5
 // 4 - red - /STB - active low device select - p8
 // 5 - brown - SCK - serial clock - sclk - p7
 
 // Also, I have fitted a battery on my breadboard to the RTC, to keep the time across power downs.
 
 // VFD
 SPI spi(p5, p6, p7); // mosi, miso, sclk (miso not used by display)
-DigitalOut cs(p8); // chip select (active low)
+DigitalOut cs(p10); // chip select (active low)
 
 // button (push)
-DigitalIn set_the_time_button (p30); // “set the time” button (active low, pullup resistor)
+DigitalIn set_the_time_button (p11); // “set the time” button (active low, pullup resistor)
 
 void DATA(unsigned char displaying) {
     // Select the device by setting chip select low
@@ -5,17 +5,17 @@
 // 2 - yellow - Vcc
 // 3 - orange - SIO - serial data - MOSI - p5
-// 4 - red - /STB - active low device select - p8
+// 4 - red - /STB - active low device select - p10
 // 5 - brown - SCK - serial clock - sclk - p7
 